@@ -3,8 +3,7 @@
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
-""" Vulnerability Test Filter class.
-"""
+"""Vulnerability Test Filter class."""
 import re
 import operator
 from typing import Dict, List, Optional
