@@ -352,6 +352,24 @@ OSPD_PARAMS = {
             + 'scan package results.'
         ),
     },
+    'max_mem_kb': {
+        'type': 'integer',
+        'name': 'max_mem_kb',
+        'default': 0,
+        'mandatory': 0,
+        'visible_for_client': True,
+        'description': (
+            'Maximum amount of memory (in MB) allowed to use for a single '
+            + 'script. If this value is set, the amount of memory put into '
+            + 'redis is tracked for every Script. If the amount of memory '
+            + 'exceeds this limit, the script is not able to set more kb '
+            + 'items. The tracked the value written into redis is only '
+            + 'estimated, as it does not check, if a value was replaced or '
+            + 'appended. The size of the key is also not tracked. If this '
+            + 'value is not set or <= 0, the maximum amount is unlimited '
+            + '(Default).'
+        ),
+    },
 }
 
 
